@@ -146,33 +146,64 @@ enum {
  *
  * @Return value: TRUE, if a collection should be used, else FALSE.
  * */
+#ifdef EOG_COLLECTION_WORKS
+
 static gint
 user_wants_collection (gint n_windows)
 {
 	GtkWidget *dlg;
 	gint ret;
-	gchar *msg;
-	
-	msg = g_new0(gchar, 120);
-	g_snprintf (msg, 120, 
-		    _("You are about to open %i windows\n"
-		      "simultanously. Do you want to open\n"
-		      "them in a collection instead?"),
-		    n_windows);
-	
-	dlg = gnome_message_box_new (msg,
-				     GNOME_MESSAGE_BOX_QUESTION,
-				     GNOME_STOCK_BUTTON_CANCEL,
-				     _("Single Windows"), _("Collection"), 
-				     NULL);		
-	ret = gnome_dialog_run (GNOME_DIALOG (dlg));
-	g_free (msg);
 
-	if (ret == -1) ret = COLLECTION_CANCEL;
+	dlg = gtk_message_dialog_new (NULL,
+				      GTK_DIALOG_MODAL,
+				      GTK_MESSAGE_QUESTION,
+				      GTK_BUTTONS_CANCEL,
+				      _("You are about to open %i windows\n"
+					"simultanously. Do you want to open\n"
+					"them in a collection instead?"),
+				      n_windows);
+	
+	gtk_dialog_add_button (GTK_DIALOG (dlg), _("Single Windows"), COLLECTION_NO);
+	gtk_dialog_add_button (GTK_DIALOG (dlg), _("Collection"), COLLECTION_YES);
+
+	ret = gtk_dialog_run (GTK_DIALOG (dlg));
+
+	if (ret != COLLECTION_NO && ret != COLLECTION_YES) 
+		ret = COLLECTION_CANCEL;
+
+	gtk_widget_destroy (dlg);
 
 	return ret;
 }
 
+#else
+
+static gint
+user_wants_collection (gint n_windows)
+{
+	GtkWidget *dlg;
+	gint ret;
+	
+	dlg = gtk_message_dialog_new (NULL,
+				      GTK_DIALOG_MODAL,
+				      GTK_MESSAGE_QUESTION,
+				      GTK_BUTTONS_CANCEL,
+				      _("You are about to open %i windows\n"
+					"simultanously. Do you want to continue?"),
+				      n_windows);
+	gtk_dialog_add_button (GTK_DIALOG (dlg), _("Open"), COLLECTION_NO);
+
+	ret = gtk_dialog_run (GTK_DIALOG (dlg));
+
+	if (ret != COLLECTION_NO)
+		ret = COLLECTION_CANCEL;
+
+	gtk_widget_destroy (dlg);
+
+	return ret;
+}
+#endif /* EOG_COLLECTION WORKS */
+
 /**
  * handle_cmdline_args:
  * @data: Pointer to the popt context provided by gnome_init_with_popt_table.
@@ -251,7 +282,6 @@ int
 main (int argc, char **argv)
 {
 	CORBA_Environment ev;
-	CORBA_ORB orb;
 	GError *error;
 	poptContext *ctx;
 
@@ -264,9 +294,6 @@ main (int argc, char **argv)
 		    argc, argv, NULL, 0, ctx);
 
 	CORBA_exception_init (&ev);
-	/* FIXME GNOME2 shouldn't be necessary, right?
-	   orb = oaf_init (argc, argv);
-	*/
 
 	error = NULL;
 	if (gconf_init (argc, argv, &error) == FALSE) {
